@@ -2,19 +2,22 @@
 
 import json
 import os
+import subprocess
 import sys
 from configparser import ConfigParser, NoOptionError
-from pathlib import Path
 from typing import Any, Iterable, Union
 
 from google.auth.credentials import Credentials
-from google.auth.exceptions import DefaultCredentialsError
+from google.auth.exceptions import DefaultCredentialsError, RefreshError
 from google.auth.transport.requests import AuthorizedSession
 from google.cloud.compute_v1 import AggregatedListInstancesRequest, InstancesClient
 from google.oauth2 import credentials, service_account
 from singleton_decorator import singleton
 
-GCP_CONFIG_PATH = f"{Path.home()}/.config/gcloud"
+from pyclvm.login import _get_config_path, _login_gcp
+from pyclvm.plt import _get_os
+
+_OS = _get_os()
 
 
 @singleton
@@ -31,7 +34,7 @@ class GcpSession:
 
         try:
             creds = os.path.normpath(
-                f"{GCP_CONFIG_PATH}/application_default_credentials.json"
+                f"{_get_config_path('GCP')}/application_default_credentials.json"
             )
             with open(creds, "rb") as src:
                 info = json.load(src)
@@ -51,7 +54,7 @@ class GcpSession:
                 )
 
         if not self._credentials:
-            self._print_exception_text_and_exit()
+            _login_gcp(**kwargs)
 
         self._authed_session = AuthorizedSession(self._credentials)
 
@@ -60,16 +63,22 @@ class GcpSession:
             self.account_email = self._authed_session.credentials.service_account_email
         except AttributeError:
             try:
+                #
                 # TODO make profile support
                 config_default = ConfigParser()
                 config_default.read(
-                    os.path.normpath(f"{GCP_CONFIG_PATH}/configurations/config_default")
+                    os.path.normpath(
+                        f"{_get_config_path('GCP')}/configurations/config_default"
+                    )
                 )
                 default_profile = config_default.sections()[0]
                 self.project_id = config_default.get(default_profile, "project")
                 self.account_email = config_default.get(default_profile, "account")
             except NoOptionError:
-                self._print_exception_text_and_exit()
+                print(
+                    "\n------\nSpecify project name\n\ne.g.\n\tclvm login gcp project=project-id"
+                )
+                sys.exit(-1)
 
         self._expired = self._authed_session.credentials.expired
         self._verify = self._authed_session.verify
@@ -79,24 +88,6 @@ class GcpSession:
         )
         self._instances = self._get_instances()
 
-    # ---
-    @staticmethod
-    def _print_exception_text_and_exit() -> str:
-        print("\n------\nNo GCP Cloud platform credentials\n")
-        print(
-            "If service account credentials json file is available, set the environment variable\n"
-            "\texport GOOGLE_APPLICATION_CREDENTIALS=/path/to/the/credentials/file\n\n",
-            "To reauthenticate existent account to Google Cloud Platform\n",
-            "\tgcloud auth login\n\n",
-            "To authenticate a new account to Google Cloud Platform:\n",
-            "\tgcloud auth login\n",
-            "\tgcloud auth application-default login\n",
-            "\tgcloud config set project project-name\n\n",
-            "To register GCP service account credentials:\n"
-            "\tgcloud auth activate-service-account --key-file=/path/to/google_application_credentials.json",
-        )
-        sys.exit(-1)
-
     # ---
     def _get_instances(self) -> Iterable:
         request = AggregatedListInstancesRequest()
@@ -149,5 +140,17 @@ class GcpSession:
         return self.project_id
 
 
+# ---
 def get_session(**kwargs) -> GcpSession:
-    return GcpSession(**kwargs)
+    try:
+        return GcpSession(**kwargs)
+    except RefreshError:
+        subprocess.run(
+            [
+                "gcloud.cmd" if _OS == "Windows" else "gcloud",
+                "auth",
+                "login",
+                "--update-adc",
+            ]
+        )
+        return GcpSession(**kwargs)
