@@ -1,6 +1,7 @@
 """session manager utilities"""
 
 from . import session
+from .clear import clear
 from .shell import shell
 
-__all__ = ["shell", "session"]
+__all__ = ["shell", "session", "clear"]
