@@ -1,6 +1,6 @@
 import os
 
-from pyclvm._common.session import make_file_name
+from pyclvm._common.session_aws import make_file_name
 from pyclvm._common.user_data import get_credentials_file_path
 
 
